import argparse
from collections.abc import Callable as Callable
from pydicom.cli.main import filespec_help as filespec_help, filespec_parser as filespec_parser
from pydicom.dataset import Dataset as Dataset

def add_subparser(subparsers: argparse._SubParsersAction) -> None: ...
def do_command(args: argparse.Namespace) -> None: ...
def SOPClassname(ds: Dataset) -> str | None: ...
def quiet_rtplan(ds: Dataset) -> str | None: ...
def quiet_image(ds: Dataset) -> str | None: ...

quiet_items: list[Callable[[Dataset], str | None] | str]

def show_quiet(ds: Dataset) -> None: ...
