from _typeshed import Incomplete
from pathlib import Path

LOGGER: Incomplete

def size_in_bytes(expr: int | float | str | None) -> None | float | int: ...
def is_dicom(file_path: str | Path) -> bool: ...
def warn_and_log(msg: str, category: type[Warning] | None = None, stacklevel: int = 1) -> None: ...
