from typing import Any, NamedTuple

class Code(NamedTuple):
    value: str
    scheme_designator: str
    meaning: str
    scheme_version: str | None = ...
    def __hash__(self) -> int: ...
    def __eq__(self, other: Any) -> Any: ...
    def __ne__(self, other: Any) -> Any: ...
