import os
from pydicom.dataset import Dataset as Dataset
from pydicom.valuerep import VR as VR
from typing import BinaryIO

def print_character(ordchr: int) -> str: ...
def filedump(filename: str | bytes | os.PathLike, start_address: int = 0, stop_address: int | None = None) -> str: ...
def datadump(data: bytes, start_address: int = 0, stop_address: int | None = None) -> str: ...
def hexdump(f: BinaryIO, start_address: int = 0, stop_address: int | None = None, show_address: bool = True) -> str: ...
def pretty_print(ds: Dataset, indent_level: int = 0, indent_chars: str = '  ') -> None: ...
